# Advanced Telegram Bot

Python library containing utils for telegram bots

[![pypi-version](https://img.shields.io/pypi/v/advanced-telegram-bot?style=flat-square)](https://pypi.org/project/advanced-telegram-bot)
![python-version](https://img.shields.io/pypi/pyversions/advanced-telegram-bot?style=flat-square)
![license](https://img.shields.io/pypi/l/advanced-telegram-bot?style=flat-square)

### Authors
made by [SDAL](https://sdal.pw/ "sdal"): 
[minish144](https://github.com/Minish144 "minish144")
& 
[usual-one](https://github.com/usual-one "usual-one")

### Available utils
- Incoming/outcoming messages service
- Locale-dependent data storage
- Logger
- Role system
- State system
- User meta data storage

### Dependencies
All the dependencies can be found in `requirements.txt` file.

### Installation
```
pip install advanced-telegram-bot
```

### Usage
Just import the class and you're good to go
```python
from advancedbot import TelegramBot
```

### Documentation & help
Help can be found in our [wiki pages](https://github.com/sdallaboratory/advanced-telegram-bot/wiki).

